#### What's new in v1.0.3 - 19/July/2024

- Added new font classes: banner (the classic), banner3, banner3d, banner4, banner_clr8x8, banner_clb8x8, banner_clr8x10, banner_clb8x10

#### What's new in v1.0.1 - 19/July/2024

- The spacing between letters was set to 0 by default. In some fonts, it is interesting to set it to 1 for better visualization of the text.
- Now you can replace the '#' by a char that you like best
- Added new font classes: banner_5x7, banner_5x8, banner_6x9, banner_6x10, banner_clr4x6, banner_clr5x8, banner_clr5x10, banner_clr6x8, banner_clr6x10, banner_clb6x10, banner_clr7x8, banner_clr7x10

#### What's new in v1.0.0 - 18/July/2024

- Initial release
- Available font classes: banner_clr5x6 and banner_clr6x6
